**1.** Install in editable mode with `pip install -e .`

**2.** Uninstall with `pip uninstall FAME-UD`

**3.** Remove additional files `rm -rf FAME_UD.egg-info`

**4.** Remove residual build artifacts `rm -rf build dist`